@@ -1,5 +1,4 @@
 /******************************************************************************
- * $Id: ogrgrassdatasource.cpp 33713 2016-03-12 17:41:57Z goatbar $
  *
  * Project:  OpenGIS Simple Features Reference Implementation
  * Purpose:  Implements OGRGRASSDataSource class.
@@ -7,7 +6,7 @@
  *
  ******************************************************************************
  * Copyright (c) 2005, Radim Blazek <radim.blazek@gmail.com>
- * Copyright (c) 2008-2010, Even Rouault <even dot rouault at mines-paris dot org>
+ * Copyright (c) 2008-2020, Even Rouault <even dot rouault at spatialys.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -32,16 +31,13 @@
 #include "cpl_conv.h"
 #include "cpl_string.h"
 
-CPL_CVSID("$Id: ogrgrassdatasource.cpp 33713 2016-03-12 17:41:57Z goatbar $");
+CPL_CVSID("$Id: ogrgrassdatasource.cpp a832da5b936bac8438f9c50e7c20e563fd94c9ff 2020-09-22 13:06:27 +0200 Markus Neteler $")
 
-#if GRASS_VERSION_MAJOR  >= 7
-#define G__setenv                G_setenv_nogisrc
-#endif
 
 /************************************************************************/
 /*                         Grass2CPLErrorHook()                         */
 /************************************************************************/
-int Grass2OGRErrorHook( char * pszMessage, int bFatal )
+static int Grass2OGRErrorHook( char * pszMessage, int bFatal )
 {
     if( !bFatal )
         CPLError( CE_Warning, CPLE_AppDefined, "GRASS warning: %s", pszMessage );
@@ -89,14 +85,10 @@ OGRGRASSDataSource::~OGRGRASSDataSource()
 /*                                Open()                                */
 /************************************************************************/
 
-#if (GRASS_VERSION_MAJOR  >= 6 && GRASS_VERSION_MINOR  >= 3) || GRASS_VERSION_MAJOR  >= 7
 typedef int (*GrassErrorHandler)(const char *, int);
-#else
-typedef int (*GrassErrorHandler)(char *, int);
-#endif
 
-int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
-                              int bTestOpen, int bSingleNewFileIn )
+int OGRGRASSDataSource::Open( const char * pszNewName, int /*bUpdate*/,
+                              int bTestOpen, int /*bSingleNewFileIn*/ )
 {
     VSIStatBuf  stat;
 
@@ -110,11 +102,11 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
     if ( strstr(pszName,"vector") == NULL || strstr(pszName,"head") == NULL )
     {
         if( !bTestOpen )
-	{
+        {
             CPLError( CE_Failure, CPLE_AppDefined,
                  "%s is not GRASS vector, access failed.\n", pszName );
-	}
-	return FALSE;
+        }
+        return FALSE;
     }
 
 /* -------------------------------------------------------------------- */
@@ -123,10 +115,10 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
     if( CPLStat( pszName, &stat ) != 0 || !VSI_ISREG(stat.st_mode) )
     {
         if( !bTestOpen )
-	{
+        {
             CPLError( CE_Failure, CPLE_AppDefined,
                  "%s is not GRASS vector, access failed.\n", pszName );
-	}
+        }
 
         return FALSE;
     }
@@ -135,15 +127,15 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 /*      Parse datasource name                                           */
 /* -------------------------------------------------------------------- */
     if ( !SplitPath(pszName, &pszGisdbase, &pszLocation,
-		    &pszMapset, &pszMap) )
+                    &pszMapset, &pszMap) )
     {
         if( !bTestOpen )
-	{
+        {
             CPLError( CE_Failure, CPLE_AppDefined,
                       "%s is not GRASS datasource name, access failed.\n",
-		      pszName );
-	}
-	return FALSE;
+                      pszName );
+        }
+        return FALSE;
     }
 
     CPLDebug ( "GRASS", "Gisdbase: %s", pszGisdbase );
@@ -184,25 +176,22 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
 /* -------------------------------------------------------------------- */
 /*      Set GRASS variables                                             */
 /* -------------------------------------------------------------------- */
-     G__setenv( "GISDBASE", pszGisdbase );
-     G__setenv( "LOCATION_NAME", pszLocation );
-     G__setenv( "MAPSET", pszMapset);
+     G_setenv_nogisrc( "GISDBASE", pszGisdbase );
+     G_setenv_nogisrc( "LOCATION_NAME", pszLocation );
+     G_setenv_nogisrc( "MAPSET", pszMapset);
      G_reset_mapsets();
      G_add_mapset_to_search_path ( pszMapset );
 
 /* -------------------------------------------------------------------- */
 /*      Open GRASS vector map                                           */
 /* -------------------------------------------------------------------- */
-#if GRASS_VERSION_MAJOR  < 7
-    Vect_set_fatal_error ( GV_FATAL_PRINT ); // Print error and continue
-#endif
     Vect_set_open_level (2);
     int level = Vect_open_old ( &map, pszMap, pszMapset);
 
     if ( level < 2 ) {
         CPLError( CE_Failure, CPLE_AppDefined,
                  "Cannot open GRASS vector %s on level 2.\n", pszName );
-	return FALSE;
+        return FALSE;
     }
 
     CPLDebug ( "GRASS", "Num lines = %d", Vect_get_num_lines(&map) );
@@ -214,15 +203,13 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
     CPLDebug ( "GRASS", "Num layers = %d", ncidx );
 
     for ( int i = 0; i < ncidx; i++ ) {
-	// Create the layer object
-	OGRGRASSLayer       *poLayer;
-
-        poLayer = new OGRGRASSLayer( i, &map );
+        // Create the layer object
+        OGRGRASSLayer *poLayer = new OGRGRASSLayer( i, &map );
 
         // Add layer to data source layer list
-	papoLayers = (OGRGRASSLayer **)
-	    CPLRealloc( papoLayers,  sizeof(OGRGRASSLayer *) * (nLayers+1) );
-	papoLayers[nLayers++] = poLayer;
+        papoLayers = (OGRGRASSLayer **)
+            CPLRealloc( papoLayers,  sizeof(OGRGRASSLayer *) * (nLayers+1) );
+        papoLayers[nLayers++] = poLayer;
     }
 
     bOpened = TRUE;
@@ -230,26 +217,10 @@ int OGRGRASSDataSource::Open( const char * pszNewName, int bUpdate,
     return TRUE;
 }
 
-/************************************************************************/
-/*                           ICreateLayer()                             */
-/************************************************************************/
-OGRLayer *
-OGRGRASSDataSource::ICreateLayer( const char * pszLayerName,
-                                 OGRSpatialReference *poSRS,
-                                 OGRwkbGeometryType eType,
-                                 char ** papszOptions )
-
-{
-    CPLError( CE_Failure, CPLE_NoWriteAccess,
-	      "CreateLayer is not supported by GRASS driver" );
-
-    return NULL;
-}
-
 /************************************************************************/
 /*                           TestCapability()                           */
 /************************************************************************/
-int OGRGRASSDataSource::TestCapability( const char * pszCap )
+int OGRGRASSDataSource::TestCapability( const char * /* pszCap*/ )
 {
     return FALSE;
 }
@@ -275,7 +246,7 @@ OGRLayer *OGRGRASSDataSource::GetLayer( int iLayer )
 /*          false - failed                                              */
 /************************************************************************/
 bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase,
-	                     char **location, char **mapset, char **map )
+                                    char **location, char **mapset, char **map )
 {
     char *p, *ptr[5], *tmp;
     int  i = 0;
@@ -285,23 +256,23 @@ bool OGRGRASSDataSource::SplitPath( char *path, char **gisdbase,
     *gisdbase = *location = *mapset = *map = NULL;
 
     if ( !path || strlen(path) == 0 )
-	return false;
+        return false;
 
     tmp = G_store ( path );
 
     while ( (p = strrchr(tmp,'/')) != NULL  && i < 5 ) {
-	*p = '\0';
+        *p = '\0';
 
-	if ( strlen(p+1) == 0 ) /* repeated '/' */
-	    continue;
+        if ( strlen(p+1) == 0 ) /* repeated '/' */
+            continue;
 
-	ptr[i++] = p+1;
+        ptr[i++] = p+1;
     }
 
     /* Note: empty GISDBASE == 0 is not accepted (relative path) */
     if ( i != 5 ) {
         free ( tmp );
-	return false;
+        return false;
     }
 
     if ( strcmp(ptr[0],"head") != 0 || strcmp(ptr[2],"vector") != 0 ) {
